==> haskell-websockets-0.12.7.3-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 websockets
version:              0.12.7.3
visibility:           public
id:                   websockets-0.12.7.3-DEwqcPvK3AB8Kl9inKEjBR
key:                  websockets-0.12.7.3-DEwqcPvK3AB8Kl9inKEjBR
license:              BSD-3-Clause
copyright:
    (c) 2010-2011 Siniša Biđin
    (c) 2011-2018 Jasper Van der Jeugt
    (c) 2011 Steffen Schuldenzucker
    (c) 2011 Alex Lang

maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:
    Siniša Biđin <sinisa@bidin.cc>
    Jasper Van der Jeugt <m@jaspervdj.be>
    Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
    Alex Lang <lang@tsurucapital.com>

stability:            experimental
homepage:             http://jaspervdj.be/websockets
synopsis:
    A sensible and clean way to write WebSocket-capable servers in Haskell.

description:
    This library allows you to write WebSocket-capable servers.

    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>

    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>

    See also:

    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>

    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>

category:             Network
abi:                  5fb9ab86700952f0a3838867fb40e29d
exposed:              True
exposed-modules:
    Network.WebSockets Network.WebSockets.Client
    Network.WebSockets.Connection Network.WebSockets.Extensions
    Network.WebSockets.Stream

hidden-modules:
    Network.WebSockets.Connection.Options
    Network.WebSockets.Extensions.Description
    Network.WebSockets.Extensions.PermessageDeflate
    Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
    Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
    Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
    Network.WebSockets.Server Network.WebSockets.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-websockets
hs-libraries:         HSwebsockets-0.12.7.3-DEwqcPvK3AB8Kl9inKEjBR
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    base64-bytestring-1.2.1.0-4q5KLdrxF6BHAwlK9Y3XXj binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-BBd0FN3VG9pHwba5nfbZ8v
    clock-0.8.4-1srh2IoelfD7KpFW0IvWK containers-0.6.7
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    streaming-commons-0.2.3.0-5Hb4wVEDVwbD1VK6TBpQes text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html:         /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.12.7.3-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 websockets
version:              0.12.7.3
visibility:           public
id:                   websockets-0.12.7.3-FGGLM1Yg2oXLcmIEyKbBB5
key:                  websockets-0.12.7.3-FGGLM1Yg2oXLcmIEyKbBB5
license:              BSD-3-Clause
copyright:
    (c) 2010-2011 Siniša Biđin
    (c) 2011-2018 Jasper Van der Jeugt
    (c) 2011 Steffen Schuldenzucker
    (c) 2011 Alex Lang

maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:
    Siniša Biđin <sinisa@bidin.cc>
    Jasper Van der Jeugt <m@jaspervdj.be>
    Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
    Alex Lang <lang@tsurucapital.com>

stability:            experimental
homepage:             http://jaspervdj.be/websockets
synopsis:
    A sensible and clean way to write WebSocket-capable servers in Haskell.

description:
    This library allows you to write WebSocket-capable servers.

    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>

    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>

    See also:

    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>

    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>

category:             Network
abi:                  45b7360bcb22cb512f71030b3629e6e3
exposed:              True
exposed-modules:
    Network.WebSockets Network.WebSockets.Client
    Network.WebSockets.Connection Network.WebSockets.Extensions
    Network.WebSockets.Stream

hidden-modules:
    Network.WebSockets.Connection.Options
    Network.WebSockets.Extensions.Description
    Network.WebSockets.Extensions.PermessageDeflate
    Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
    Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
    Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
    Network.WebSockets.Server Network.WebSockets.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/websockets-0.12.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-websockets
hs-libraries:         HSwebsockets-0.12.7.3-FGGLM1Yg2oXLcmIEyKbBB5
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    async-2.2.5-KSZIoACaSMlHctQ7vOTAKz
    attoparsec-0.14.4-4lxImiie977LVZ07Q4RuOa base-4.17.2.1
    base64-bytestring-1.2.1.0-Ho7haZ0JPmRAFS27fbQFVQ binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-71BYPVg6lDO17X4ot5DP2
    clock-0.8.4-BfW1P0bdt1CGyPa9TcZH5J containers-0.6.7
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    network-3.1.4.0-6nVv84Orn5X1dkWXH7HumR
    random-1.2.1.2-23MFWqKwy7yBKL8EDiRtc8
    streaming-commons-0.2.3.0-2sgnwK2oaCS651NTgsATfs text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html:         /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
